// Generated by dts-bundle-generator v6.5.0

import React from 'react';
import { JSXElementConstructor, ReactNode } from 'react';

export interface EventWeek {
	weekStart: Date;
	weekEnd: Date;
	daysInWeek: Date[];
	events: InternalCalendarEvent[];
	eventsOnDays: {
		date: Date;
		events: InternalCalendarEvent[];
	}[];
}
export declare type CalendarState = {
	/** The current visible month */
	currentMonth: Date;
	/** The DateTimeAdapter that is being utilized */
	dateAdapter: DateTimeAdapter;
	/** Array with localized names of the days of the week */
	daysOfWeek: string[];
	/** Advance the calendar one month */
	onNextMonth: () => void;
	/** Decrease the calendar by one month */
	onPrevMonth: () => void;
	/** Calendar with events that will be displayed */
	calendarWithEvents: EventWeek[];
};
/**
 * This object represents an event that is supplied by the client
 */
export interface CalendarEvent {
	/** Unique *external* ID of the event */
	id: string;
	/** Start date of the event (ISO format w/Timezone) */
	start: string;
	/** End date of the event  (ISO format w/Timezone) */
	end: string;
	/** Text that will be visible on the event */
	summary: string;
	/** Visible color of the event *(css color value)* */
	color: string;
}
/**
 * This object represents an event that is displayed on the calendar
 */
export interface InternalCalendarEvent {
	/** Unique *external* ID of the event */
	id: string;
	/** Start date of the event */
	start: Date;
	/** End date of the event */
	end: Date;
	/** Text that will be visible on the event */
	summary: string;
	/** Visible color of the event *(css color value)* */
	color: string;
}
/**
 * Common interface for porting date libraries so they can be used with Schedulely
 */
export interface DateTimeAdapter {
	/** Add the specified number of months to the date. Using a negative value will subtract that amount. */
	addMonthsToDate: (date: Date, amount: number) => Date;
	/** Returns all days in the month, split apart by week. Includes leading/trailing days. */
	getCalendarView: (date: Date) => Date[][];
	/** Get the day number component for a given date */
	getDayNumber: (date: Date) => number;
	/** Get full names of all days of the week */
	getDaysOfWeek: (displaySize: DisplaySize) => string[];
	/** Get the day of week grid index for the end of the event. Used for positioning within the Week css-grid. */
	getGridEndIndex: (eventEndDate: Date, endOfWeek: Date) => number;
	/** Get the day of week index for the start of the event. Used for positioning within the Week css-grid */
	getGridStartIndex: (eventDate: Date, startOfWeek: Date) => number;
	/** Get the full name of the month for a given date */
	getMonthName: (date: Date) => string;
	/** Get the year component for a given date */
	getYear: (date: Date) => number;
	/** Convert and ISO format string to a Date object */
	convertIsoToDate: (isoDate: string) => Date;
	/** Returns true if the date represent today */
	isDateToday: (date: Date) => boolean;
	/** Does the event fall within or span the supplied week */
	isEventInWeek: (eventStartDate: Date, eventEndDate: Date, week: Date[]) => boolean;
	/** Compare two dates, returns true if they are in the same month, in the same year */
	isSameMonth: (firstDate: Date, secondDate: Date) => boolean;
}
export declare enum DisplaySize {
	tiny = 0,
	medium = 1,
	large = 2
}
/**
 * Props interface for More Events Indicator components
 */
export interface MoreEventsIndicatorProps {
	events: InternalCalendarEvent[];
}
/**
 * Type used for creating MoreEventsIndicatorComponent
 */
export declare type MoreEventsIndicatorComponent = JSXElementConstructor<MoreEventsIndicatorProps>;
export interface SchedulelyComponents {
	dayOfWeekComponent: DayOfWeekComponent;
	dayComponent: DayComponent;
	forwardNavigationButtonComponent: NavigationButtonComponent;
	backwardNavigationButtonComponent: NavigationButtonComponent;
	headerBannerComponent: HeaderBannerComponent;
	dayHeaderComponent: DayHeaderComponent;
	eventComponent: EventComponent;
	moreEventsIndicatorComponent: MoreEventsIndicatorComponent;
}
/**
 * Props interface for creating Day components
 */
export interface DayComponentProps {
	/** Does this date represent the current month (used for coloring trailing/leading days) */
	isCurrentMonth: boolean;
	/** Child elements within the day */
	children?: JSX.Element | JSX.Element[];
}
/**
 * Type used for creating DayComponent
 */
export declare type DayComponent = JSXElementConstructor<DayComponentProps>;
/**
 * Props interface for creating Day components
 */
export interface DayHeaderComponentProps {
	/** The day number portion of the Date */
	dateNumber: number;
	/** Does this date represent today? */
	isToday: boolean;
}
/**
 * Type used for creating DayComponent
 */
export declare type DayHeaderComponent = JSXElementConstructor<DayHeaderComponentProps>;
/** Props used when creating a DayOfWeek */
export interface DayOfWeekProps {
	/** The the name of the day */
	dayName: string;
}
/** Displays the name of the day at the top of the calendar column */
export declare type DayOfWeekComponent = JSXElementConstructor<DayOfWeekProps>;
/**
 * Props interface for creating Event components
 */
export interface EventComponentProps {
	event: InternalCalendarEvent;
	isHovered: boolean;
}
/**
 * Type used for creating EventComponent
 */
export declare type EventComponent = JSXElementConstructor<EventComponentProps>;
/** Props used when creating a HeaderBanner */
export interface HeaderBannerProps {
	/** The current month the calendar is displaying */
	month: string;
	/** The current year the calendar is displaying */
	year: number;
}
/** The month/year banner displayed at the top of the calendar */
export declare type HeaderBannerComponent = JSXElementConstructor<HeaderBannerProps>;
/** Props used when creating a NavigationButton */
export interface NavigationButtonComponentProps {
	/** Action taken when button is clicked */
	onClick: () => void;
	children?: JSX.Element | JSX.Element[];
}
/** Button used for forward/backward navigation of months */
export declare type NavigationButtonComponent = JSXElementConstructor<NavigationButtonComponentProps>;
/** Properties used to initialize Schedulely */
export interface SchedulelyProps {
	/** DateAdapter used to process dates */
	dateAdapter?: DateTimeAdapter;
	/** Component overrides */
	schedulelyComponents?: Partial<SchedulelyComponents>;
	/** List of events to display */
	events: CalendarEvent[];
	/** Additional class names to apply to the root div */
	additionalClassNames?: string[];
	/** Name of theme to display */
	theme?: string;
}
export interface HighlightEventState {
	/** Set the ID of the currently highlighted event */
	setHighlight: (eventId: string) => void;
	/** Clear the currently value for highlightedEvent */
	clearHighlight: () => void;
	/** Check if the eventId equals the currently highlighted event */
	isHighlighted: (eventId: string) => boolean;
}
/**
 * Create an instance of Schedulely
 * @param {SchedulelyProps} param0 Schedulely configuration properties
 * @returns
 */
export declare const Schedulely: ({ dateAdapter, schedulelyComponents, events, theme, additionalClassNames, }: SchedulelyProps) => JSX.Element;
export declare const DefaultBackButton: NavigationButtonComponent;
export declare const DefaultDay: DayComponent;
export declare const DefaultDayHeader: DayHeaderComponent;
/**
 * This component is the header that appears at the top of each day of the week
 * @param param0 Name of the day of the week
 * @returns DayOfWeek component
 */
export declare const DefaultDayOfWeek: DayOfWeekComponent;
/**
 * This component is the UI representation of events on the calendar
 * @returns DefaultEvent Component
 */
export declare const DefaultEvent: EventComponent;
export declare const DefaultForwardButton: NavigationButtonComponent;
export declare const DefaultHeaderBanner: HeaderBannerComponent;
export declare const DefaultMoreEventsIndicator: MoreEventsIndicatorComponent;
/**
 * Shim type to avoid import date-fns
 * Could be brittle if they change type
 */
export interface Interval {
	start: number | Date;
	end: number | Date;
}
/**
 * Shim type to avoid import date-fns
 * Could be brittle if they change type
 */
export interface Locale {
	code?: string;
	formatDistance?: (...args: Array<any>) => any;
	formatRelative?: (...args: Array<any>) => any;
	localize?: {
		ordinalNumber: (...args: Array<any>) => any;
		era: (...args: Array<any>) => any;
		quarter: (...args: Array<any>) => any;
		month: (...args: Array<any>) => any;
		day: (...args: Array<any>) => any;
		dayPeriod: (...args: Array<any>) => any;
	};
	formatLong?: {
		date: (...args: Array<any>) => any;
		time: (...args: Array<any>) => any;
		dateTime: (...args: Array<any>) => any;
	};
	match?: {
		ordinalNumber: (...args: Array<any>) => any;
		era: (...args: Array<any>) => any;
		quarter: (...args: Array<any>) => any;
		month: (...args: Array<any>) => any;
		day: (...args: Array<any>) => any;
		dayPeriod: (...args: Array<any>) => any;
	};
	options?: {
		weekStartsOn?: 0 | 1 | 2 | 3 | 4 | 5 | 6;
		firstWeekContainsDate?: 1 | 2 | 3 | 4 | 5 | 6 | 7;
	};
}
/**
 * Simple interface for using date-fns with Schedulely
 *
 * Functions can be passed directly from import.
 */
export interface DateFnsFunctions {
	addDays: (date: number | Date, amount: number) => Date;
	eachDayOfInterval: (interval: Interval, options?: {
		step?: number | undefined;
	} | undefined) => Date[];
	eachWeekOfInterval: (interval: Interval, options?: {
		locale?: Locale | undefined;
		weekStartsOn?: 0 | 1 | 2 | 3 | 4 | 5 | 6 | undefined;
	} | undefined) => Date[];
	format: (date: number | Date, format: string, options?: {
		locale?: Locale | undefined;
		weekStartsOn?: 0 | 1 | 2 | 3 | 4 | 5 | 6 | undefined;
		firstWeekContainsDate?: number | undefined;
		useAdditionalWeekYearTokens?: boolean | undefined;
		useAdditionalDayOfYearTokens?: boolean | undefined;
	} | undefined) => string;
	startOfMonth: (date: number | Date) => Date;
	startOfWeek: (date: number | Date, options?: {
		locale?: Locale | undefined;
		weekStartsOn?: 0 | 1 | 2 | 3 | 4 | 5 | 6 | undefined;
	} | undefined) => Date;
	addMonths: (date: number | Date, amount: number) => Date;
	isSameWeek(dateLeft: Date | number, dateRight: Date | number, options?: {
		locale?: Locale | undefined;
		weekStartsOn?: 0 | 1 | 2 | 3 | 4 | 5 | 6 | undefined;
	} | undefined): boolean;
}
/**
 * Create a Schedulely compatible DateConvertor from date-fns.
 */
export declare const createDateFnsConvertor: (datefns: DateFnsFunctions) => DateTimeAdapter;
export declare const createDefaultAdapter: (locale?: string) => DateTimeAdapter;
export declare const useCalendar: () => CalendarState;
export declare const useComponents: () => SchedulelyComponents;
export declare const useEventHighlight: () => HighlightEventState;
/**
 * This component controls the layout of the names of the days of the week at the top of the calendar
 * @returns DayOfWeekLayout Component
 */
export declare const DayOfWeekLayout: () => JSX.Element;
export interface EventPositionLayoutProps {
	event: InternalCalendarEvent;
	startIndex: number;
	endIndex: number;
	children: ReactNode;
}
/**
 * This component controls the position of an individual event within an event week
 * @returns EventPositionLayout Component
 */
export declare const EventPositionLayout: ({ event, startIndex, endIndex, children, }: EventPositionLayoutProps) => JSX.Element;
export interface EventLayoutProps {
	events: InternalCalendarEvent[];
	daysInweek: Date[];
}
/**
 * This component controls the layout of an individual events within a week
 * @returns EventLayout Component
 */
export declare const EventWeekLayout: ({ events, daysInweek }: EventLayoutProps) => JSX.Element;
/**
 * This component controls the layout of the header that display the controls and the current month/year description
 * @returns HeaderLayout component
 */
export declare const HeaderLayout: () => JSX.Element;
/**
 * This component controls the layout of the weeks of the calendar
 * @returns MonthLayout Component
 */
export declare const MonthLayout: () => JSX.Element;
export interface WeekLayoutProps {
	dates: Date[];
	eventsOnDays: {
		date: Date;
		events: InternalCalendarEvent[];
	}[];
}
/**
 * This component controls the layout of an individual weeks worth of days
 * @returns WeekLayout Component
 */
export declare const WeekLayout: ({ dates, eventsOnDays }: WeekLayoutProps) => JSX.Element;
export declare const CalendarContext: import("react").Context<CalendarState | null>;
export interface CalendarProviderProps {
	dateAdapter: DateTimeAdapter;
	initialDate?: Date;
	calendarEvents: CalendarEvent[];
	children: ReactNode;
}
/**
 * The provides access to data and behaviors that control the calendar
 * @param param0 CalendarProviderProps
 * @returns CalendarContext.Provider component
 */
export declare const CalendarProvider: ({ dateAdapter, initialDate, calendarEvents, children, }: CalendarProviderProps) => JSX.Element;
export declare const ComponentContext: React.Context<SchedulelyComponents | null>;
export interface ComponentProviderProps {
	calendarComponents?: Partial<SchedulelyComponents>;
	children: ReactNode;
}
/**
 * Provides the layout components with the visible calendar components
 * @param param0 Partial<SchedulelyComponents> that will over-ride the default components
 * @returns ComponentProvider component
 */
export declare const ComponentProvider: ({ calendarComponents, children, }: ComponentProviderProps) => JSX.Element;
export declare const HighlightContext: import("react").Context<HighlightEventState | null>;
/**
 * Enables highlighting of events that span multiple weeks. Kinda hacky but it works.
 * @param {ReactNode} children Child nodes
 * @returns HighlightProvider component
 */
export declare const HighlightProvider: ({ children }: {
	children: ReactNode;
}) => JSX.Element;

export {};
